@@ -176,7 +176,7 @@ class ConvNextBlock(nn.Module):
         self,
         dim,
         act = nn.ReLU(),
-        ds_kernel_size = 3,
+        ds_kernel_size = 7,
         mult = 4,
     ):
         """
@@ -196,20 +196,6 @@ class ConvNextBlock(nn.Module):
     def forward(self, x):
         return self.net(x) + x
 
-class ResBlock(nn.Module):
-    def __init__(self, chan):
-        super().__init__()
-        self.net = nn.Sequential(
-            nn.Conv2d(chan, chan, 3, padding = 1),
-            nn.ReLU(),
-            nn.Conv2d(chan, chan, 3, padding = 1),
-            nn.ReLU(),
-            nn.Conv2d(chan, chan, 1)
-        )
-
-    def forward(self, x):
-        return self.net(x) + x
-
 class VQGanVAE(nn.Module):
     def __init__(
         self,
@@ -223,7 +209,7 @@ class VQGanVAE(nn.Module):
         vq_commitment_weight = 1.,
         l2_recon_loss = False,
         use_hinge_loss = True,
-        num_resnet_blocks = 1,
+        num_conv_blocks = 1,
         vgg = None,
         **kwargs
     ):
@@ -245,9 +231,9 @@ class VQGanVAE(nn.Module):
             self.encoders.append(nn.Sequential(nn.Conv2d(enc_dim_in, enc_dim_out, 4, stride = 2, padding = 1), nn.ReLU()))
             self.decoders.append(nn.Sequential(nn.ConvTranspose2d(dec_dim_in, dec_dim_out, 4, stride = 2, padding = 1), nn.ReLU()))
 
-        for _ in range(num_resnet_blocks):
-            self.encoders.append(ResBlock(dims[-1]))
-            self.decoders.append(ResBlock(dims[-1]))
+        for _ in range(num_conv_blocks):
+            self.encoders.append(ConvNextBlock(dims[-1]))
+            self.decoders.append(ConvNextBlock(dims[-1]))
 
         self.encoders.insert(0, nn.Conv2d(channels, dim, 3, padding = 1))
         self.decoders.append(nn.Conv2d(dim, channels, 1))
